@@ -5,7 +5,7 @@ use Params::Validate ();
 use Params::CallbackRequest::Exceptions (abbr => [qw(throw_bad_params)]);
 
 use vars qw($VERSION);
-$VERSION = '1.13';
+$VERSION = '1.15';
 use constant DEFAULT_PRIORITY => 5;
 use constant REDIRECT => 302;
 
@@ -19,8 +19,10 @@ my $is_num = { 'valid priority' => sub { $_[0] =~ /^\d$/ } };
 
 # Use Apache::RequestRec for mod_perl 2
 my $ap_req_class = defined $mod_perl::VERSION && $mod_perl::VERSION >= 1.99
-  ? 'Apache::RequestRec'
-  : 'Apache';
+    ? 'Apache::RequestRec'
+    : defined $mod_perl2::VERSION
+        ? 'Apache2::RequestRec'
+        : 'Apache';
 
 BEGIN {
     # The object-oriented interface is only supported with the use of
@@ -29,10 +31,8 @@ BEGIN {
     # that we can tell ApacheHandler::WithCallbacks that they exist and
     # are loaded.
     unless ($] < 5.006) {
-        eval {
-            require Attribute::Handlers;
-            require Class::ISA;
-        }
+        require Attribute::Handlers;
+        require Class::ISA;
     }
 
     # Build read-only accessors.
@@ -42,6 +42,7 @@ BEGIN {
                       priority
                       cb_key
                       pkg_key
+                      requester
                       trigger_key
                       value )) {
         no strict 'refs';
@@ -50,50 +51,53 @@ BEGIN {
     *class_key = \&pkg_key;
 }
 
-my %valid_params =
-  ( cb_request      =>
-    { isa        => 'Params::CallbackRequest',
+my %valid_params = (
+    cb_request => { isa => 'Params::CallbackRequest' },
+
+    params => {
+        type => Params::Validate::HASHREF,
     },
 
-    params =>
-    {  type      => Params::Validate::HASHREF,
+    apache_req => {
+        isa      => $ap_req_class,
+        optional => 1,
     },
 
-    apache_req   =>
-    { isa        => $ap_req_class,
-      optional   => 1,
+    priority => {
+        type      => Params::Validate::SCALAR,
+        callbacks => $is_num,
+        optional  => 1,
+        desc      => 'Priority'
     },
 
-    priority =>
-    { type      => Params::Validate::SCALAR,
-      callbacks => $is_num,
-      optional  => 1,
-      desc      => 'Priority'
+    cb_key => {
+        type     => Params::Validate::SCALAR,
+        optional => 1,
+        desc     => 'Callback key'
     },
 
-    cb_key =>
-    { type      => Params::Validate::SCALAR,
-      optional  => 1,
-      desc      => 'Callback key'
+    pkg_key => {
+        type     => Params::Validate::SCALAR,
+        optional => 1,
+        desc     => 'Package key'
     },
 
-    pkg_key =>
-    { type      => Params::Validate::SCALAR,
-      optional  => 1,
-      desc      => 'Package key'
+    trigger_key => {
+        type     => Params::Validate::SCALAR,
+        optional => 1,
+        desc     => 'Trigger key'
     },
 
-    trigger_key =>
-    { type      => Params::Validate::SCALAR,
-      optional  => 1,
-      desc      => 'Trigger key'
+    value => {
+        optional => 1,
+        desc     => 'Callback value'
     },
 
-    value =>
-    { optional  => 1,
-      desc      => 'Callback value'
-    },
-  );
+    requester => {
+        optional => 1,
+        desc     => 'Requesting object'
+    }
+);
 
 sub new {
     my $proto = shift;
@@ -481,6 +485,15 @@ passed one to C<< Params::CallbackRequest->request >>. This will be most
 useful in a mod_perl environment, of course. Use Apache:FakeRequest in
 tests to emmulate the behavior of an Apache request object.
 
+=head3 requester
+
+  my $r = $cb->requester;
+
+Returns the object that executed the callback by calling C<request()> on a
+Params::CallbackRequest object. Only available if the C<requester> parameter
+is passed to C<< Params::CallbackRequest->request >>. This can be useful for
+callbacks to get access to the object that executed the callbacks.
+
 =head3 priority
 
   my $priority = $cb->priority;
@@ -1032,7 +1045,7 @@ David Wheeler <david@kineticode.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003 by David Wheeler
+Copyright 2003-2004 David Wheeler
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
